<?php
/* --------------------------------------------------------------
 MyLayoutAssetsLoader.php 2020-11-26
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

declare(strict_types=1);

namespace GXModules\Vendor\MyModule;

use Gambio\Core\Application\ValueObjects\Url;
use Gambio\Core\TemplateEngine\LayoutData;
use Gambio\Core\TemplateEngine\Loader;

class MyLayoutAssetsLoader implements Loader
{
    private const KEY_SCRIPTS               = 'dynamic_script_assets';
    private const KEY_ENABLE_LEGACY_SCRIPTS = 'enable_legacy_dynamic_script_assets';
    private const KEY_STYLES                = 'dynamic_style_assets';
    private const KEY_ENABLE_LEGACY_STYLES  = 'enable_legacy_dynamic_style_assets';
    
    /**
     * @var Url
     */
    private $url;
    
    
    public function __construct(Url $url)
    {
        $this->url = $url;
    }
    
    
    public function load(LayoutData $data): void
    {
        $assetDir = "{$this->url->base()}/GXModules/Vendor/MyModule";
        
        // for legacy pages, the flags must be enabled to load the dynamic assets
        $data->assign(self::KEY_ENABLE_LEGACY_SCRIPTS, true);
        $data->assign(self::KEY_ENABLE_LEGACY_STYLES, true);
        
        $dynamicScriptAsset = $data->get(self::KEY_SCRIPTS);
        $dynamicScriptAsset .= <<<HTML
<script src="$assetDir/my_script.js"></script>
HTML;
        
        $dynamicStyleAsset = $data->get(self::KEY_STYLES);
        $dynamicStyleAsset .= <<<HTML
<link rel="stylesheet" href="$assetDir/my_style.css">
HTML;
        
        $data->assign(self::KEY_SCRIPTS, $dynamicScriptAsset);
        $data->assign(self::KEY_STYLES, $dynamicStyleAsset);
    }
}